@@ -39,6 +39,19 @@
 #' }
 eem_parafac <- function(eem_list, comps, maxit = 500, normalise = TRUE, const = c("nonneg","nonneg","nonneg"), nstart = 10, ctol = 10^-4, cores = parallel::detectCores(logical=FALSE), verbose = FALSE, ...){
   #eem_list <- eem_list %>% eem_red2smallest()
+  # require(staRdom)
+  # require(multiway)
+  # require(tidyverse)
+  # load(file="../eem_list_1.0.12.Rda")
+  # eem_list <- eem_list_ex
+  # maxit = 2500
+  # normalise = TRUE
+  # const = c("nonneg","nonneg","nonneg")
+  # #const = rep("ortnon",3)
+  # nstart = 15
+  # ctol = 10^-7
+  # cores <- 2
+  # verbose = TRUE
   eem_array <- eem2array(eem_list)
   if(normalise){
     if(verbose) cat("EEM matrices are normalised!",fill=TRUE)
@@ -46,18 +59,20 @@ eem_parafac <- function(eem_list, comps, maxit = 500, normalise = TRUE, const =
   }
   if(verbose) cat(paste0(cores," cores are used for the calculation."),fill=TRUE)
   res <- lapply(comps,function(comp){
+    #comp <- 6
     if(verbose) cat(paste0("calculating ",comp," components model..."),fill=TRUE)
-    #comp <- 5
-    #eem_array %>% dim()
     cl <- NULL
     if(cores > 1){
     cl <- makeCluster(cores, type="PSOCK")
-    clusterExport(cl, c("eem_array","comp","maxit","nstart","const","ctol","cores"), envir=environment())
+    clusterExport(cl, c("eem_array","comp","maxit","const","ctol","cores"), envir=environment())
     clusterEvalQ(cl, library(multiway))
     }
-    cpresult <- parafac(eem_array, nfac = comp, const = const, maxit = maxit, parallel = (cores > 1), cl = cl, ctol = ctol, nstart = nstart, ...)
+    cpresult <- parafac_conv(eem_array, nfac = comp, const = const, maxit = maxit, parallel = (cores > 1), cl = cl, ctol = ctol, nstart = nstart, output = "best", verbose = verbose, ...) #, ...
     if(cores > 1){
-    stopCluster(cl)
+      stopCluster(cl)
+    }
+    if(cpresult$cflag != 0){
+      warning("The PARAFAC model with ",comp," component",ifelse(comp > 1, "s", "")," did not converge! Increasing the number of initialisations (nstart) might solve the problem.")
     }
     attr(cpresult,"norm_factors") <- attr(eem_array,"norm_factors")
     rownames(cpresult$B) <- eem_list[[1]]$em
@@ -67,12 +82,70 @@ eem_parafac <- function(eem_list, comps, maxit = 500, normalise = TRUE, const =
     colnames(cpresult$A) <- labComp
     colnames(cpresult$B) <- labComp
     colnames(cpresult$C) <- labComp
+    # small issue with multiway: slightly negative values are possible despite using nonnegative constraints
+    non <- grepl("no|unsmpn",const)
+    if(non[1]) cpresult$A[cpresult$A < 0] <- 0
+    if(non[2]) cpresult$B[cpresult$B < 0] <- 0
+    if(non[3]) cpresult$C[cpresult$C < 0] <- 0
     return(cpresult)
   })
   mostattributes(res) <- attributes(eem_array)
   return(res)
 }
 
+#' Calculate a PARAFAC model similar to and using \code{\link[multiway]{parafac}}.
+#'
+#' @description Please refer to \code{\link[multiway]{parafac}} for input parameters and details. This wrapper function ensures `nstart` converging models are calculated. On the contrary, parafac calculates `nstart` models regardless if they are converging.
+#'
+#' @param X array
+#' @param nstart number of converging models to calculate
+#' @param verbose logical, whether more information is supplied
+#' @param output Output the best solution (default) or output all nstart solutions.
+#' @param cl cluster to be used for parallel processing
+#' @param ... arguments passed on to \code{\link[multiway]{parafac}}
+#'
+#' @return either a parafac model or a list of parafac models
+#'
+#' @seealso \code{\link[multiway]{parafac}}
+#'
+#' @export
+#'
+#' @examples
+#' \donttest{
+#' # sorry, no example provided yet
+#' }
+parafac_conv <- function(X, nstart, verbose = FALSE, output = c("best", "all"), cl = NULL, ...){
+  nmod <- 0
+  ntot <- 0
+  cpresult_all <- list()
+  while(nmod < nstart & ntot <= 10 * nstart){
+    pred_factor <- ifelse(ntot == 0, 1, ifelse(nmod == 0, 3, ntot/nmod/2))
+    if(verbose) cat("Due to previous model calculations, pred_factor was set", pred_factor, fill = TRUE)
+    nmiss <- ceiling((nstart - nmod) * pred_factor / 8) * 8
+    if(verbose) cat("start run with",nmiss,"models...",fill = TRUE)
+    if(!is.null(cl)){
+      clusterExport(cl, c("nmiss"), envir=environment())
+    }
+    cpresult <- parafac(X, nstart = nmiss, output = "all", cl = cl, ...) #, ...
+    cpresult_conv <- cpresult[lapply(cpresult,`[[`,"cflag") %>% unlist() == 0]
+    cpresult_all <- c(cpresult_all,cpresult_conv)
+    nmod <- length(cpresult_all)
+    ntot <- ntot + nmiss
+    if(verbose) cat(length(cpresult_conv),"models converged successfully in this run!", fill = TRUE)
+    if(verbose) cat(length(cpresult_all),"models calculated!", fill = TRUE)
+  }
+  if(verbose) cat(nmod,"out of",ntot,"models converged!",fill=TRUE)
+  if(output[1] == "best"){
+    sses <- cpresult_all %>% lapply(`[[`,"SSE") %>% unlist()
+    cpresult_all <- cpresult_all[[which.min(sses)]]
+  } else if (output[1] == "all"){
+    sses <- cpresult_all %>% lapply(`[[`,"SSE") %>% unlist()
+    cpresult_all <- cpresult_all[[sses[sort(order(-sses)[1:nstart])]]]
+  }
+  if(ntot >= 10 * nstart) warning("Maximum number of starts reached without generating the desired number of valid models.")
+  cpresult_all
+}
+
 #' Rescale B and C modes of PARAFAC model
 #'
 #' @description B and C modes (emission and excitation wavelengths) are rescaled to RMS of value newscale. This is compensated in A mode (sample loadings).
@@ -605,7 +678,7 @@ splithalf <- function(eem_list, comps, splits = NA, rand = FALSE, normalise = TR
       if(verbose) cat("EEM matrices are normalised!",fill=TRUE)
     }
     cat(paste0("Calculating PARAFAC models with split-half data..."),fill=TRUE)
-    pb <- txtProgressBar(max = 6, style=3)
+    pb <- txtProgressBar(max = length(spl_eems), style=3)
   }
   fits <- lapply(1:length(spl_eems),function(i){
     mod <- eem_parafac(spl_eems[[i]],comps=comps,normalise = normalise,maxit=maxit,nstart = nstart, cores = cores,ctol = ctol,verbose=FALSE,...)
@@ -843,6 +916,7 @@ tcc <- function(maxl_table,na.action="na.omit"){
 #'
 #' @param pfmodel PARAFAC model
 #' @param file string, path to outputfile. The directory must exist, the file will be created or overwritten if already present.
+#' @param Fmax rescale modes so the A mode shows the maximum fluorescence. As openfluor does not accept values above 1, this is a way of scaling the B and C modes to a range between 0 and 1.
 #'
 #' @return txt file
 #' @export
@@ -852,7 +926,7 @@ tcc <- function(maxl_table,na.action="na.omit"){
 #' @examples
 #'   data(pf_models)
 #'   eempf_openfluor(pf4[[1]],file.path(tempdir(),"openfluor_example.txt"))
-eempf_openfluor <- function(pfmodel,file){
+eempf_openfluor <- function(pfmodel, file, Fmax = TRUE){
   if(!dir.exists(dirname(file.path(file)))){
     stop("The path to your file does not contain an existing directory. Please enter a correct path!")
   }
@@ -932,6 +1006,7 @@ eempf4analysis <- function(pfmodel,eem_list = NULL, absorbance = NULL, cuvl = NU
 #'
 #' @param pfmodel PARAFAC model
 #' @param export file path to export table
+#' @param Fmax rescale modes so the A mode shows the maximum fluorescence
 #' @param ... additional parameters passed to \code{\link[utils]{write.table}}
 #'
 #' @return data frame
@@ -946,7 +1021,9 @@ eempf4analysis <- function(pfmodel,eem_list = NULL, absorbance = NULL, cuvl = NU
 #' data(pf_models)
 #'
 #' factor_table <- eempf_export(pf4[[1]])
-eempf_export<- function(pfmodel,export = NULL,...){
+eempf_export<- function(pfmodel,export = NULL, Fmax = TRUE,...){
+  pfmodel <- norm2A(pfmodel)
+  if(Fmax) pfmodel <- eempf_rescaleBC(pfmodel)
   tabs <- list(pfmodel$A %>%
                  as.data.frame() %>%
                  tibble::rownames_to_column("sample") #%>%
@@ -997,7 +1074,7 @@ eempf_export<- function(pfmodel,export = NULL,...){
 eempf_corcondia <- function(pfmodel,eem_list,divisor="core"){
   arr <- eem_list %>% eem2array()
   if(!is.null(attr(eem_list,"norm_factors"))) arr <- arr %>% norm_array()
-  multiway::corcondia(arr,pfmodel,divisor=divisor)
+  corcondia(arr,pfmodel,divisor=divisor)
 }
 
 #' Calculating EEMqual which is an indicator of a PARAFAC model's quality
