@@ -34,17 +34,13 @@ library("staRdom")
 
 ## ----eval=TRUE, include=TRUE---------------------------------------------
 folder <- system.file("extdata/EEMs/", package = "staRdom") # folder containing example EEMs
-eem_list <- eem_read_csv(folder) # in case you use your own data, just replace folder by a path. e.g. "C:/folder/another folder" and use eem_read if you do not have plain csv tables to import
+eem_list <- eem_read(folder, recursive = TRUE, import_function = eem_csv) # in case you use your own data, just replace folder by a path. e.g. "C:/folder/another folder" and change import_function according to instrument.
 
 ## ----eval=FALSE, include=TRUE--------------------------------------------
-#  eem_list <- eem_read(folder)
+#  eem_list <- eem_read(folder, import_function = "cary")
 
-## ----eval=FALSE, include=TRUE--------------------------------------------
-#  install.packages("devtools") # Run this only, if devtools is not installed already.
-#  devtools::install_github("PMassicotte/eemR")
-
-## ----eval=TRUE, fig.width=7, message=FALSE, warning=FALSE, include=TRUE, paged.print=TRUE----
-eem_overview_plot(eem_list, spp=8)
+## ----eval=TRUE, fig.width=7, fig.heigth = 5, message=FALSE, warning=FALSE, include=TRUE, paged.print=TRUE----
+eem_overview_plot(eem_list, spp=9, contour = TRUE)
 
 ## ----eval=TRUE, include=TRUE---------------------------------------------
 absorbance_path = system.file("extdata/absorbance", package = "staRdom") # load example data, set a path without using system.file to use your own data e.g. "C:/folder/another folder"
@@ -88,20 +84,20 @@ eem_list <- eem_extend2largest(eem_list, interpolation = 1, extend = FALSE, core
 # blank subtraction
 eem_list <- eem_remove_blank(eem_list)
 
-## ----eval=TRUE, fig.width=7, message=FALSE, warning=FALSE, include=TRUE, paged.print=TRUE----
-eem_overview_plot(eem_list, spp=8)
+## ----eval=TRUE, fig.width=7, fig.heigth = 5, message=FALSE, warning=FALSE, include=TRUE, paged.print=TRUE----
+eem_overview_plot(eem_list, spp=9, contour = TRUE)
 
 ## ----eval=TRUE, include=TRUE---------------------------------------------
 eem_list <- eem_ife_correction(eem_list,absorbance, cuvl = 5)
 
-## ----eval=TRUE, fig.width=7, message=FALSE, warning=FALSE, include=TRUE, paged.print=TRUE----
-eem_overview_plot(eem_list, spp=8)
+## ----eval=TRUE, fig.width=7, fig.heigth = 5, message=FALSE, warning=FALSE, include=TRUE, paged.print=TRUE----
+eem_overview_plot(eem_list, spp=9, contour = TRUE)
 
 ## ----eval=TRUE, include=TRUE---------------------------------------------
 eem_list <- eem_raman_normalisation2(eem_list, blank = "blank")
 
-## ----eval=TRUE, fig.width=7, message=FALSE, warning=FALSE, include=TRUE, paged.print=TRUE----
-eem_overview_plot(eem_list, spp=8)
+## ----eval=TRUE, fig.width=7, fig.heigth = 5, message=FALSE, warning=FALSE, include=TRUE, paged.print=TRUE----
+eem_overview_plot(eem_list, spp=9, contour = TRUE)
 
 ## ----eval=TRUE, include=TRUE---------------------------------------------
 eem_list <- eem_extract(eem_list, c("nano", "miliq", "milliq", "mq", "blank"),ignore_case = TRUE)
@@ -114,14 +110,14 @@ remove_scatter_width <- c(15,15,15,15)
 
 eem_list <- eem_rem_scat(eem_list, remove_scatter = remove_scatter, remove_scatter_width = remove_scatter_width)
 
-## ----eval=TRUE, fig.width=7, message=FALSE, warning=FALSE, include=TRUE, paged.print=TRUE----
-eem_overview_plot(eem_list, spp=6)
+## ----eval=TRUE, fig.width=7, fig.heigth = 5, message=FALSE, warning=FALSE, include=TRUE, paged.print=TRUE----
+eem_overview_plot(eem_list, spp=9, contour = TRUE)
 
 ## ----eval=TRUE, include=TRUE---------------------------------------------
 eem_list <- eem_interp(eem_list, cores = cores, type = 1, extend = FALSE)
 
-## ----eval=TRUE, fig.width=7, message=FALSE, warning=FALSE, include=TRUE, paged.print=TRUE----
-eem_overview_plot(eem_list, spp=6)
+## ----eval=TRUE, fig.width=7, fig.heigth = 5, message=FALSE, warning=FALSE, include=TRUE, paged.print=TRUE----
+eem_overview_plot(eem_list, spp=9, contour = TRUE)
 
 ## ----eval=TRUE, include=TRUE---------------------------------------------
 dil_data <- meta["dilution"]
@@ -129,7 +125,7 @@ dil_data <- meta["dilution"]
 eem_list <- eem_dilution(eem_list,dil_data)
 
 ## ----eval=FALSE, fig.width=7, message=FALSE, warning=FALSE, include=TRUE, paged.print=TRUE----
-#  eem_overview_plot(eem_list, spp=6) # plot spared, due to no dilution it looks like the previous plot.
+#  eem_overview_plot(eem_list, spp=9) # plot spared, due to no dilution it looks like the previous plot.
 
 ## ----eval=TRUE, include=TRUE---------------------------------------------
 eem4peaks <- eem_smooth(eem_list, n = 4)
@@ -191,7 +187,7 @@ slope_parms
 #    file <- file %>%
 #      gsub("^\\s+|\\s+$", "", .) %>% # trim white spaces in filenames
 #      sub(pattern = "(.*)\\..*$", replacement = "\\1", .) # remove file extension from sample name
-#    eem <- list(sample = file,x = dreem_data$XcRU[n,,] %>% as.matrix(),ex = dreem_data$Ex %>% as.vector(), em = dreem_data$Em.in %>% as.vector(),location = "drEEM/dataset/")
+#    eem <- list(file = paste0("drEEM/dataset/",file),sample = file,x = dreem_data$XcRU[n,,] %>% as.matrix(),ex = dreem_data$Ex %>% as.vector(), em = dreem_data$Em.in %>% as.vector(), location = "drEEM/dataset/")
 #    class(eem) <- "eem"
 #    attr(eem, "is_blank_corrected") <- TRUE
 #    attr(eem, "is_scatter_corrected") <- FALSE
@@ -203,7 +199,7 @@ slope_parms
 #    `class<-`("eemlist")
 #  
 #  # add sample name suffix, R has sometimes troubles, when sample names start with a number.
-#  eem_names(eem_list) <- paste0("dreem_",eem_names(eem_list))
+#  eem_names(eem_list) <- paste0("d",eem_names(eem_list))
 
 ## ----eval=FALSE, include=TRUE--------------------------------------------
 #  ol <- function(x){x==("bl") | x == "0A"}
@@ -212,61 +208,65 @@ slope_parms
 
 ## ----message=FALSE, warning=FALSE, include=FALSE-------------------------
 data(eem_list) # load example from staRdom package, this is just necessary for the actual tutorial creation. Remove this line, if you downloaded the drEEM dataset right above and want to use that.
-eem_ex <- eem_extract(eem_list,sample ="^dreem_667sf$",keep=TRUE)
+eem_ex <- eem_extract(eem_list,sample ="^d667sf$",keep=TRUE)
 
-## ----include = TRUE, eval = FALSE----------------------------------------
-#  eem_list <- eem_rem_scat(eem_list, remove_scatter = c(TRUE, TRUE, TRUE, TRUE), remove_scatter_width = c(15,15,18,19), interpolation = FALSE, cores = cores)
+## ----include = TRUE, eval = TRUE-----------------------------------------
+eem_list <- eem_rem_scat(eem_list, remove_scatter = c(TRUE, TRUE, TRUE, TRUE), remove_scatter_width = c(15,15,18,19), interpolation = FALSE, cores = cores)
 
 ## ----include = FALSE, eval = TRUE----------------------------------------
-eem_ex <- eem_rem_scat(eem_ex, remove_scatter = c(TRUE, TRUE, TRUE, TRUE), remove_scatter_width = c(15,15,18,19), interpolation = FALSE, cores = cores)
+eem_ex <- eem_ex %>% 
+  eem_extract(sample = "^d667sf$", keep = TRUE) %>%
+  eem_rem_scat(eem_ex, remove_scatter = c(TRUE, TRUE, TRUE, TRUE), remove_scatter_width = c(15,15,18,19), interpolation = FALSE, cores = cores) %>%
+  `eem_names<-`("d667sf_2_scatter") %>%
+  eem_bind(eem_ex,.)
 
 ## ----include=TRUE,eval=FALSE---------------------------------------------
 #  eem_list <- eem_import_dir(dir)
 
 ## ----include=TRUE, eval = FALSE------------------------------------------
 #  eem_list %>%
-#    eem_extract(sample = "^dreem_667sf$", keep = TRUE) %>%
-#    ggeem()
+#    eem_extract(sample = "^d667sf$", keep = TRUE) %>%
+#    ggeem(contour = TRUE)
 
-## ----include=TRUE, eval = FALSE------------------------------------------
-#  eem_ex %>%
-#    ggeem()
+## ----include=FALSE, eval = TRUE------------------------------------------
+eem_ex %>% 
+  ggeem(contour = TRUE)
 
-## ------------------------------------------------------------------------
+## ----eval=TRUE-----------------------------------------------------------
 eem_list <- eem_list %>% eem_range(ex = c(250,Inf), em = c(0,580))
 
 ## ----message=FALSE, warning=FALSE, include=FALSE-------------------------
 eem_ex <- eem_ex %>% 
-  eem_extract(sample = "^dreem_667sf$", keep = TRUE) %>%
+  eem_extract(sample = "^d667sf_2_scatter$", keep = TRUE) %>%
   eem_range(ex = c(250,Inf), em = c(0,580)) %>%
-  `eem_names<-`("dreem_667sf_2_cut") %>%
+  `eem_names<-`("d667sf_3_cut") %>%
   eem_bind(eem_ex,.)
 
 ## ----eval = TRUE, message = FALSE, warning = FALSE, include = FALSE------
 eem_ex <- eem_ex %>%
-  eem_extract(sample = "^dreem_667sf_2_cut$", keep = TRUE) %>%
+  eem_extract(sample = "^d667sf_3_cut$", keep = TRUE) %>%
   eem_setNA(sample = 1, ex = 345:350, interpolate = FALSE) %>% # sample 1 in staRdom data is sample 176 in drEEM data!
   eem_setNA(em = 560:576, ex = 280:295, interpolate = FALSE) %>%
-  `eem_names<-`("dreem_667sf_3_rem_noise") %>%
+  `eem_names<-`("d667sf_4_rem_noise") %>%
   eem_bind(eem_ex,.) 
 
-## ----include=TRUE, eval=FALSE--------------------------------------------
-#  eem_list <- eem_list %>%
-#    eem_setNA(sample = 176, ex = 345:350, interpolate = FALSE) %>%
-#    eem_setNA(em = 560:576, ex = 280:295, interpolate = FALSE)
+## ----include=TRUE, eval=TRUE---------------------------------------------
+eem_list <- eem_list %>%
+  eem_setNA(sample = 176, ex = 345:350, interpolate = FALSE) %>%
+  eem_setNA(em = 560:576, ex = 280:295, interpolate = FALSE)
 
-## ----eval = FALSE, include = TRUE----------------------------------------
-#  eem_list <- eem_interp(eem_list, type = 1, extend = FALSE, cores = cores)
+## ----eval = TRUE, include = TRUE-----------------------------------------
+eem_list <- eem_interp(eem_list, type = 1, extend = FALSE, cores = cores)
 
 ## ----message=FALSE, warning=FALSE, include=FALSE-------------------------
 eem_ex <- eem_ex %>% 
-  eem_extract(sample = "^dreem_667sf_3_rem_noise$", keep = TRUE) %>%
+  eem_extract(sample = "^d667sf_4_rem_noise$", keep = TRUE) %>%
   eem_interp(type = 1, extend = FALSE, cores = cores) %>%
-  `eem_names<-`("dreem_667sf_4_interp") %>%
+  `eem_names<-`("d667sf_5_interp") %>%
   eem_bind(eem_ex,.)
 
 ## ----echo=FALSE, message=FALSE, warning=FALSE, fig.width=7---------------
-ggeem(eem_ex)
+ggeem(eem_ex, contour = TRUE)
 
 ## ----include=TRUE, eval = TRUE-------------------------------------------
 data(pf_models)
@@ -277,9 +277,9 @@ dim_min <- 3
 dim_max <- 7
 
 ## ----eval=FALSE,include=TRUE---------------------------------------------
-#  nstart <- 20 # number of similar models from which best is chosen
+#  nstart <- 25 # number of similar models from which best is chosen
 #  maxit = 5000 # maximum number of iterations in PARAFAC analysis
-#  ctol <- 10^-5 # tolerance in PARAFAC analysis
+#  ctol <- 10^-6 # tolerance in PARAFAC analysis
 #  
 #  # calculating PARAFAC models, one for each number of components
 #  pf1 <- eem_parafac(eem_list, comps = seq(dim_min,dim_max), normalise = FALSE, const = c("uncons", "uncons", "uncons"), maxit = maxit, nstart = nstart, ctol = ctol, cores = cores)
@@ -291,18 +291,19 @@ dim_max <- 7
 #  pf1 <- lapply(pf1, eempf_rescaleBC, newscale = "Fmax")
 #  pf1n <- lapply(pf1n, eempf_rescaleBC, newscale = "Fmax")
 
-## ----eval=FALSE, include=FALSE, fig.width=7, fig.height=6----------------
-#  eempf_compare(pf1)
+## ----eval=FALSE, include=TRUE, fig.width=7, fig.height=6-----------------
+#  # This plot is not shown, because the components violate the assumptions for fluorescence peaks (negative fluorescence). Please try, if you are interested.
+#  eempf_compare(pf1, contour = TRUE)
 
 ## ----eval=TRUE, include=TRUE, fig.width=7, fig.height=6------------------
-eempf_compare(pf1n)
+eempf_compare(pf1n, contour = TRUE)
 
 ## ----eval=TRUE, include=TRUE, fig.width=7--------------------------------
 # check for correlation between components table
-eempf_cortable(pf1n[[4]])
+eempf_cortable(pf1n[[4]], normalisation = FALSE)
 
 ## ----eval=TRUE, include=TRUE, fig.width=7, fig.height=6------------------
-eempf_corplot(pf1n[[4]], progress = FALSE)
+eempf_corplot(pf1n[[4]], progress = FALSE, normalisation = FALSE)
 
 ## ----eval=FALSE,include=TRUE---------------------------------------------
 #  pf2 <- eem_parafac(eem_list, comps = seq(dim_min,dim_max), normalise = TRUE, const = c("nonneg", "nonneg", "nonneg"), maxit = maxit, nstart = nstart, ctol = ctol, cores = cores)
@@ -311,7 +312,7 @@ eempf_corplot(pf1n[[4]], progress = FALSE)
 #  pf2 <- lapply(pf2, eempf_rescaleBC, newscale = "Fmax")
 
 ## ----eval=TRUE, include=TRUE, fig.width=7, fig.height=6------------------
-eempf_compare(pf2)
+eempf_compare(pf2, contour = TRUE)
 
 ## ----fig.width=7---------------------------------------------------------
 # calculate leverage
@@ -328,7 +329,7 @@ exclude <- eempf_leverage_ident(cpl,qlabel=0.1)
 #  # samples, excitation and emission wavelengths to exclude, makes sense after calculation of leverage
 #  exclude <- list("ex" = c(),
 #                  "em" = c(),
-#                  "sample" = c("dreem_sfb676psp","dreem_sgb447wt")
+#                  "sample" = c("dsfb676psp","dsgb447wt")
 #  )
 #  
 #  # exclude outliers if neccessary. if so, restart analysis
@@ -339,12 +340,22 @@ exclude <- eempf_leverage_ident(cpl,qlabel=0.1)
 #  pf3 <- lapply(pf3, eempf_rescaleBC, newscale = "Fmax")
 
 ## ----eval=TRUE, include=TRUE, fig.width=7, fig.height=6------------------
-eempf_compare(pf3)
+eempf_compare(pf3, contour = TRUE)
 
+## ----eval=TRUE, include=TRUE, fig.width=7--------------------------------
 eempf_leverage_plot(eempf_leverage(pf3[[4]]),qlabel=0.1)
 
-## ----eval=TRUE, include=TRUE, fig.width=7, fig.height=6------------------
-eempf_residuals_plot(pf3[[4]], eem_list, residuals_only = TRUE, select = eem_list %>% eem_names() %>% .[c(1:4,205,208)], spp = 6, cores = cores)
+## ----eval=FALSE, include=TRUE, fig.width=7, fig.height=6-----------------
+#  eempf_residuals_plot(pf3[[4]], eem_list, residuals_only = TRUE, select = c("d0680sfK", "d1266sf", "d1268sfK", "d1543sfK", "dsfb676psp", "dsgb447wt"), spp = 6, cores = cores, contour = TRUE)
+
+## ----eval=TRUE, echo=FALSE, message=FALSE, warning=FALSE, fig.width=7, fig.height=6----
+data("eem_list_outliers")
+eem_list %>%
+  eem_extract(5:15) %>%
+  eem_bind(eem_list_outliers) %>%
+  eem_red2smallest() %>%
+  eempf_residuals_plot(pf3[[4]], ., residuals_only = TRUE, spp = 6, cores = cores, contour = TRUE) %>%
+  invisible()
 
 ## ----eval=FALSE, include=TRUE--------------------------------------------
 #  ctol <- 10^-8 # decrease tolerance in PARAFAC analysis
@@ -355,25 +366,23 @@ eempf_residuals_plot(pf3[[4]], eem_list, residuals_only = TRUE, select = eem_lis
 #  
 #  pf4 <- lapply(pf4, eempf_rescaleBC, newscale = "Fmax")
 
-## ----eval=TRUE, include=TRUE, fig.width=7, fig.height=6------------------
+## ----eval=TRUE, include=TRUE, fig.width=4, fig.height=6------------------
 # just one model, not really a need to compare
-eempf_compare(pf4)
+eempf_compare(pf4, contour = TRUE)
 
+## ----eval=TRUE, include=TRUE, fig.width=7--------------------------------
 eempf_leverage_plot(eempf_leverage(pf4[[1]])) # [[4]] means the 4th model in the list, 6 component model in that case
 
+
+## ----eval=TRUE, include=TRUE, fig.width=7, fig.height=6------------------
 eempf_corplot(pf4[[1]], progress = FALSE)
 
 ## ----eval=FALSE, include=TRUE--------------------------------------------
-#  # choosing 10% of the samples, but 10 minimum
-#  eems_rand <- eem_names(eem_list_ex)[sample(1:length(eem_list_ex),max(10,ceiling(length(eem_list_ex)*0.1)))]
-#  # extracting those from the whole list
-#  eem_list_short <- eem_extract(eem_list_ex, sample = eems_rand, keep = TRUE)
-#  
 #  # calculating a rough model, nstart is high (100) but ctol is 2 magnitudes larger or at least 0.01
-#  pf5 <- eem_parafac(eem_list_short, comps = 6, normalise = TRUE, const = c("nonneg", "nonneg", "nonneg"), maxit = maxit, nstart = 100, ctol = min(ctol*100,0.01), cores = cores)
+#  pf5 <- eem_parafac(eem_list, comps = 6, normalise = TRUE, const = c("nonneg", "nonneg", "nonneg"), maxit = maxit, nstart = 100, ctol = min(ctol*100,0.01), cores = cores)
 #  
 #  # plot is not shown
-#  ggeem(pf5[[1]])
+#  ggeem(pf5[[1]], contour = TRUE)
 #  
 #  nstart <- 5
 #  pf4 <- eem_parafac(eem_list_ex, comps = 6, normalise = TRUE, const = c("nonneg", "nonneg", "nonneg"), maxit = maxit, nstart = nstart, ctol = ctol, cores = cores, Bstart = pf5[[1]]$B, Cstart = pf5[[1]]$C)
@@ -381,16 +390,16 @@ eempf_corplot(pf4[[1]], progress = FALSE)
 #  pf4 <- lapply(pf4, eempf_rescaleBC, newscale = "Fmax")
 #  
 #  # plot is not shown
-#  ggeem(pf4[[1]])
+#  ggeem(pf4[[1]], contour = TRUE)
 
 ## ----eval=TRUE, include=TRUE, fig.width=7, fig.height=6------------------
-eempf_comp_load_plot(pf4[[1]])
+eempf_comp_load_plot(pf4[[1]], contour = TRUE)
 
-# eempf_plot_comps(pf4[4], type = 2) # this function can be used to view the B- and C-modes
+# eempf_plot_comps(pf4[1], type = 2) # this function can be used to view the B- and C-modes
 
 ## ----eval=TRUE, include=TRUE, fig.width=7, fig.height=8------------------
 # plot components in each sample, residual and whole sample
-eempf_residuals_plot(pf4[[1]], eem_list, select = eem_names(eem_list)[10:14], cores = cores)
+eempf_residuals_plot(pf4[[1]], eem_list, select = eem_names(eem_list)[10:14], cores = cores, contour = TRUE)
 
 ## ----eval=FALSE, include=TRUE--------------------------------------------
 #  #calculate split_half analysis
@@ -426,7 +435,7 @@ pf4_wOutliers <- A_missing(eem_list, pfmodel = pf4[[1]], cores = cores)
 #  varimp <- eempf_varimp(pf4[[1]], eem_list_ex, cores = cores)
 
 ## ----fig.width=7---------------------------------------------------------
-# get current model names
+# get current model names (none set so far!)
 names(pf3)
 # set new model names, number of models must be equal to number of names
 names(pf3) <- c("3 components", "4 components xy","5 components no outliers","6 components","7 components")
@@ -446,13 +455,13 @@ eempf_comp_names(pf3) <- list(c("A1","B1","C1"), # names for 1st model
 )
 
 pf4[[1]] %>%
-  ggeem()
+  ggeem(contour = TRUE)
 
 ## ----eval=FALSE, include = TRUE------------------------------------------
 #  eempf_openfluor(pf4[[1]], file = "my_model_openfluor.txt")
 
 ## ----eval=FALSE, include = TRUE------------------------------------------
-#  eempf_report(pf4[[1]], export = "my_model_openfluor.txt", eem_list = eem_list, shmodel = sh, performanec = TRUE)
+#  eempf_report(pf4[[1]], export = "parafac_report.html", eem_list = eem_list, shmodel = sh, performance = TRUE)
 
 ## ----echo=FALSE, message=FALSE, warning=FALSE----------------------------
 write.bibtex(file="references2.bib")
